#
# spec file for package libpst
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2008 Bharath Acharya
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libpst
Version:        0.6.76
Release:        1.4
Summary:        Library and utilities for reading Personal Storage Table files
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Email/Utilities
URL:            http://www.gnome.org/projects/evolution/
Source0:        http://www.five-ten-sg.com/libpst/packages/%{name}-%{version}.tar.gz

BuildRequires:  gcc-c++
BuildRequires:  gd-devel
BuildRequires:  libgsf-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(zlib)
Suggests:       %{name}-doc

%description
The libpst utilities include readpst, which can convert email messages
to both mbox and MH mailbox formats, pst2ldif, which can convert the
contacts to .ldif format for import into LDAP databases, and pst2dii,
which can convert email messages to the DII load file format used by
Summation.

%package -n libpst4
Summary:        A library for reading Personal Storage Table files
Group:          System/Libraries

%description -n libpst4
libpst is a library that can decode the email messages stored in a
.pst (Personal Storage Table) file as created by Outlook.

%package devel
Summary:        Development files for libpst, a .pst file reader
Group:          Development/Libraries/C and C++
Requires:       libpst4 = %{version}

%description devel
libpst is a library that can decode the email messages stored in a
"PST" file as created by Outlook.

This subpackage contains the header files for developing
applications that want to make use of libpst.

%package doc
Summary:        Documentation for the pst utilities in html format
BuildArch:      noarch

%description doc
The libpst-doc package contains the html documentation for the pst
utilities.  You do not need to install it if you just want to use
the libpst utilities.

%prep
%autosetup -p1

%build
%configure \
        --disable-static \
        --enable-libpst-shared \
        --disable-python
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%ldconfig_scriptlets -n libpst4

%files
%{_mandir}/man?/*
%{_bindir}/lspst
%{_bindir}/nick2ldif
%{_bindir}/pst2ldif
%{_bindir}/readpst

%files -n libpst4
%license COPYING
%{_libdir}/libpst.so.*

%files devel
%{_includedir}/libpst-4/
%{_libdir}/pkgconfig/libpst.pc
%{_libdir}/libpst.so

%files doc
%doc %{_datadir}/doc/%{name}-%{version}

%changelog
* Tue Aug 30 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.6.76:
  + Fix rfc2231 encoding when saving messages to .eml and .msg
    formats.
- Package COPYING with license macro in shared library package.
- Drop libpst-glib-2.68.patch: No longer needed.
- Split out doc sub-package and add a Suggests in main package.
- Use ldconfig_scriptlets macro for post(un) handling.
* Fri Mar 19 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Add libpst-glib-2.68.patch: Fix build against glib 2.68.
* Thu Feb 18 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.6.75:
  + Fix from Debian for vcard version format.
- Changes from version 0.6.74:
  + Many changes for Debian.
- Changes from version 0.6.73:
  + Fix segfault in pst_close().
- Changes from version 0.6.72:
  + Add -l and -f options to lspst.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Sat Sep  9 2017 jengelh@inai.de
- Update package descriptions.
* Thu Sep  7 2017 zaitor@opensuse.org
- Update to version 0.6.71:
  + Add support for the OST 2013 format.
  + Content-Disposition filename key fix for outlook compatibility.
- Add pkgconfig(zlib) BuildRequires: New dependency.
* Sun Feb 19 2017 zaitor@opensuse.org
- Update to version 0.6.70:
  + pst_getID2 must not recurse into children.
* Mon Nov  7 2016 dimstar@opensuse.org
- Update to version 0.6.69:
  + Fix bugs in code allowing folders containing multiple item
    types.
* Thu Sep 15 2016 zaitor@opensuse.org
- Update to version 0.6.68:
  + Allow folders containing multiple item types.
  + Better detection of valid internet headers.
* Thu Jul 14 2016 zaitor@opensuse.org
- Update to version 0.6.67:
  + Multiple bug fixes and an optimization.
* Tue Jun  7 2016 jengelh@inai.de
- Remove duplicate copy of documentation files (make install copies
  them already).
- Remove undocumented libpst4 requires.
* Fri Apr 15 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
* Sun Dec 27 2015 zaitor@opensuse.org
- Update to version 0.6.66:
  + Added Content-ID header support.
* Mon Sep 14 2015 dimstar@opensuse.org
- Update to version 0.6.65:
  + Fix multiple Content-Type headers.
  + Debug level output.
* Fri Mar 20 2015 zaitor@opensuse.org
- Update to version 0.6.64:
  + Fixes for attachment processing and body encodings that contain
    embedded null chars.
* Sat Jan  4 2014 dimstar@opensuse.org
- Update to version 0.6.63:
  + Fixed buffer overrun in LIST_COPY_TIME.
- Changes from version 0.6.62:
  + Old dependency filter breaks file coloring.
* Wed Aug  7 2013 dimstar@opensuse.org
- Update to version 0.6.61:
  + Move documentation to unversioned directory.
* Sun Jun 16 2013 zaitor@opensuse.org
- Update to version 0.6.60:
  + Add AC_USE_SYSTEM_EXTENSIONS.
  + Add readpst -a option for attachment stripping.
- Drop libpst-system-extensions.patch, fixed upstream.
- Drop libtool BuildRequires and call to autoreconf, as we do not
  carry any patches.
* Wed May 22 2013 dimstar@opensuse.org
- Update to version 0.6.59:
  + Add autoconf checking for libgsf.
- Add libpst-system-extensions.patch: ensure we have _GNU_SOURCE
  defined in order to have get_current_dir_name prototypes.
- Add libtool BuildRequires and call to autoreconf, as above patch
  touches the build system.
* Tue Mar 19 2013 zaitor@opensuse.org
- Update to version 0.6.58:
  + Fix From quoting on embedded rfc/822 messages.
* Sat Jan  5 2013 dimstar@opensuse.org
- Update to version 0.6.57:
  + Remove useless dependencies (only in tarball shipped .spec
    file).
- Changes from version 0.6.56:
  + Merge -m .msg files code into main branch.
- Add libgsf-devel BuildRequires: new dependency for the .msg files
  code.
* Tue Aug 14 2012 dimstar@opensuse.org
- Update to version 0.6.55:
  + preserve bcc headers, space after colon is not required in
    header fields.
* Fri Dec 30 2011 zaitor@opensuse.org
- Update to version 0.6.54:
  + Embedded rfc822 messages might contain rtf encoded bodies.
* Mon Jul 11 2011 dimstar@opensuse.org
- Update to version 0.6.53:
  + Add Status: header in output
  + Allow fork for parallel processing of individual email folders
    in separate mode
- Drop libpst-no-date-time.patch: fixed upstream.
- No longer SUSE_ASNEEDED=0: the build system no longer causes an
  issue.
* Fri Jun 17 2011 vuntz@opensuse.org
- Stop using source service to download the tarball, as Factory
  will move away from this.
* Fri May 27 2011 dimstar@opensuse.org
- Add libpst-no-date-time.patch: do not embed date/time stamps in
  the binaries. Patch taken from upstream:
  http://hg.five-ten-sg.com/libpst/raw-rev/898118c3675e
* Mon May 23 2011 dimstar@opensuse.org
- Update to version 0.6.52:
  + Fix dangling freed pointer in embedded rfc822 message
    processing
  + Allow broken outlook internet header field; it sometimes
    contains fragments of the message body rather than headers
* Fri Apr 29 2011 dimstar@opensuse.org
- Update to version 0.6.51:
  + Fix for buffer overrun; attachment size from the secondary
  + List of mapi elements overwrote proper size from the primary
    list of mapi elements.
- Changes from version 0.6.50:
  + rfc2047 and rfc2231 encoding for non-ascii headers and
    attachment filenames.
- Use source services: download_url, recompress and set_version.
* Tue Sep 14 2010 vuntz@opensuse.org
- Update to version 0.6.49:
  + fix to ignore embedded objects that are not email messages
* Fri Sep  3 2010 dimstar@opensuse.org
- Update to version 0.6.48:
  + fix for broken internet headers from Outlook.
  + fix ax_python.m4 to look for python2.7.
  + use mboxrd from quoting for output formats with multiple.
    messages per file.
  + use no from quoting for output formats with single message per
    file.
* Mon Jul 19 2010 dimstar@opensuse.org
- Update to version 0.6.47:
  + Solaris fixes.
  + Fix output file name numbering to start at 1 rather than 2.
- Changes from version 0.6.46:
  + Prefer libpthread over librt for finding sem_init function.
  + Changes in implicit dso linking semantics.
* Sat Dec 12 2009 dimstar@opensuse.org
- Update to version 0.6.45:
  + Export categories and notes into vcards and vcalendar
    appointments.
* Tue Sep 22 2009 dimstar@opensuse.org
- Update to version 0.6.44:
  + patch from Lee Ayres to add file name extensions in separate
    mode
  + patches from Justin Greer, Chris White, Roberto Polli; better
    rfc822 embedded message decoding
  + patch from Fridrich Strba to build with DJGPP DOS
    cross-compiler
* Thu Jul 30 2009 dominique-obs@leuenberger.net
- Update to version 0.6.41
  + fix ax_python detection - should not use locate command
  + fedora 11 has python2.6, remove pdf version of the man pages
  + fedora > 10 moved to boost-python-devel
  + many changes including shared library soname
  + add pst_attach_to_mem() back into the shared library interface.
  + properly add trailing mime boundary in all modes.
  + avoid putting mixed item types into the same output folder
  + fix utf-7 conversions, don't produce empty attachment files
    in separate mode
  + bump version for fedora cvs tagging mistake
  + track character set individually for each mapi element, avoid
    emitting bogus empty email messages into contacts and calendar.
  + improve decoding of multipart/report and message/rfc822
    mime types.
  + patch from Fridrich Strba for building on mingw, and autoconf
    cleanup, better mime headers
  + improve handling of content-type charset values in mime parts
  + patch from Chris Eagle to build on cygwin
  + process emails with type PST_TYPE_OTHER, fix malloc error and
    possible segfault
  + fix title bug with old schema in pst2ldif, also escape commas
    in distinguished names per rfc4514.
  + add configure option --enable-dii=no, fixes from Robert Harris
    for pst2ldif.
  + Initial work on a .so shared library from Bharath Acharya.
  + Fixes for iconv on Mac from Justin Greer.
- Removed AutoReqProv: on; it's default now
- Library soname was bumped, so renamed libpst0 to libpst4
- Removed so_fixes.patch and bug_fix.patch (upstreamed)
- Export SUSE_ASNEEDED to fix build. Will need a patch.
- Pass --enable-libpst-shared and --disable-python to configure.
- Use more appropriate RPM group.
* Tue Sep  9 2008 abharath@suse.de  
- Added
  + so_fixes.patch - Generate shared libraries
  + bug_fix.patch - Add a current_attach member to the pst_item structure.
* Fri Sep  5 2008 abharath@suse.de  
- Release version 0.6.17:
  + Initial check-in.
